#!/usr/bin/env node

import fs from "fs";
import inquirer from "inquirer";
import shell from "shelljs";

import { QUESTIONS } from "./questions.js";
import { handleDirectoryContent } from "./handleDirectoryContent.js";

const handleNextApp = (typescript, projectName) => {
  shell.exec(
    `yarn create next-app ${typescript ? "--typescript" : ""} ${projectName} &&
    cd ${projectName} &&
    yarn add -D prettier eslint-config-prettier lint-staged &&
    npx husky-init && yarn &&
    npx husky add .husky/pre-commit "npx lint-staged"
    `,
    () => {
      const packageJson = fs.readFileSync(`./${projectName}/package.json`);
      fs.writeFileSync(
        `./${projectName}/package.json`,
        JSON.stringify({
          ...JSON.parse(packageJson),
          "lint-staged": {
            "**/*": "prettier --write --ignore-unknown",
          },
        }),
      );
      handleDirectoryContent("next", projectName);
    },
  );
};

inquirer.prompt(QUESTIONS).then((answers) => {
  const { framework, typescript, projectName } = answers;

  switch (framework) {
    default:
    case "next":
      handleNextApp(typescript, projectName);
      break;
  }
});
